@@ -74,8 +74,10 @@ def get_pollutant_enum_name(file_handle, pollutant_name: str) -> str:
 
 def get_pollutant_enum(
         file_handle,
-        element_type: Union[shared_enum.SubcatchAttribute, shared_enum.NodeAttribute, shared_enum.LinkAttribute,
-                            shared_enum.SystemAttribute],
+        element_attribute: Union[shared_enum.SubcatchAttribute,
+                                 shared_enum.NodeAttribute,
+                                 shared_enum.LinkAttribute,
+                                 shared_enum.SystemAttribute],
         pollutant_name: str) -> Union[shared_enum.SubcatchAttribute, shared_enum.NodeAttribute,
                                       shared_enum.LinkAttribute, shared_enum.SystemAttribute]:
     """
@@ -84,24 +86,26 @@ def get_pollutant_enum(
 
     Args:
         file_handle:  SWMM output file handle
-        element_type: Element type
+        element_attribute: Element type
         pollutant_name (str) : Pollutant name
 
     Returns:
 
     """
     pollutant_enum_name = get_pollutant_enum_name(file_handle, pollutant_name)
-    return element_type[pollutant_enum_name]
+    return element_attribute[pollutant_enum_name]
 
 
-def create_netcdf_from_swmm(swmm_output_file: str, netcdf_output_file: str):
+def create_netcdf_from_swmm(swmm_output_file: str, netcdf_output_file: str, read_by_series=True):
     """
     Creates netcdf output from SWMM output
 
     Args:
-        swmm_output_file: SWMM output filepath
+        read_by_series (bool): Read whole timeseries at time
 
-        netcdf_output_file: NetCDF
+        swmm_output_file (str): SWMM output filepath
+
+        netcdf_output_file (str): NetCDF
 
     Returns:
 
@@ -124,7 +128,7 @@ def create_netcdf_from_swmm(swmm_output_file: str, netcdf_output_file: str):
     netcdf_output.createDimension(dimname='time', size=None)
     nc_time_variable = netcdf_output.createVariable(
         varname="time",
-        datatype='f8',
+        datatype=np.float,
         dimensions=("time",),
 
     )
@@ -251,30 +255,105 @@ def create_netcdf_from_swmm(swmm_output_file: str, netcdf_output_file: str):
     # system attributes
     nc_system_attributes_names_variable[:] = np.array(system_attributes, dtype=object)
 
-    for t in range(num_steps):
+    if read_by_series:
         # catchment attributes
-        for j in range(num_catchments):
-            catchment_results = output.get_subcatch_result(p_handle=file_handle, timeIndex=t, subcatchIndex=j)
-            nc_catchment_timeseries[j, :, t] = np.array(catchment_results[0:num_catchment_attributes])
+        for i in range(len(catchment_attributes)):
+            catchment_attribute = catchment_attributes[i]
+            catchment_attribute_enum = shared_enum.SubcatchAttribute[catchment_attribute]
+
+            j: int = 0
+            for catchment_id, catchment_index in catchments.items():
+                catchment_series = output.get_subcatch_series(
+                    p_handle=file_handle,
+                    subcatchIndex=catchment_index,
+                    attr=catchment_attribute_enum,
+                    startPeriod=0,
+                    endPeriod=num_steps
+                )
+
+                nc_catchment_timeseries[j, i, :] = np.array(catchment_series, dtype=np.float)
+                netcdf_output.sync()
+                j += 1
 
         # node attributes
-        for j in range(num_nodes):
-            node_results = output.get_node_result(p_handle=file_handle, timeIndex=t, nodeIndex=j)
-            nc_node_timeseries[j, :, t] = np.array(node_results[0:num_node_attributes])
+        for i in range(len(node_attributes)):
+            node_attribute = node_attributes[i]
+            node_attribute_enum = shared_enum.NodeAttribute[node_attribute]
+
+            j: int = 0
+            for node_id, node_index in nodes.items():
+                node_series = output.get_node_series(
+                    p_handle=file_handle,
+                    nodeIndex=node_index,
+                    attr=node_attribute_enum,
+                    startPeriod=0,
+                    endPeriod=num_steps
+                )
+
+                nc_node_timeseries[j, i, :] = np.array(node_series, dtype=np.float)
+                netcdf_output.sync()
+                j += 1
 
         # link attributes
-        for j in range(num_links):
-            link_results = output.get_link_result(p_handle=file_handle, timeIndex=t, linkIndex=j)
-            nc_link_timeseries[j, :, t] = np.array(link_results[0:num_link_attributes])
+        for i in range(len(link_attributes)):
+            link_attribute = link_attributes[i]
+            link_attribute_enum = shared_enum.LinkAttribute[link_attribute]
+
+            j: int = 0
+            for link_id, link_index in links.items():
+                link_series = output.get_link_series(
+                    p_handle=file_handle,
+                    linkIndex=link_index,
+                    attr=link_attribute_enum,
+                    startPeriod=0,
+                    endPeriod=num_steps
+                )
+
+                nc_link_timeseries[j, i, :] = np.array(link_series, dtype=np.float)
+                netcdf_output.sync()
+                j += 1
 
         # system attributes
-        system_results = output.get_system_result(p_handle=file_handle, timeIndex=t, dummyIndex=0)
-        nc_system_timeseries[:, t] = np.array(system_results[0:num_system_attributes])
+        for i in range(len(system_attributes)):
+            system_attribute = system_attributes[i]
+            system_attribute_enum = shared_enum.SystemAttribute[system_attribute]
 
-        if t % 5000 == 0:
+            system_series = output.get_system_series(
+                p_handle=file_handle,
+                attr=system_attribute_enum,
+                startPeriod=0,
+                endPeriod=num_steps
+            )
+
+            nc_system_timeseries[i, :] = np.array(system_series)
             netcdf_output.sync()
+    else:
+        for t in range(num_steps):
+            # catchment attributes
+            for j in range(num_catchments):
+                catchment_results = output.get_subcatch_result(p_handle=file_handle, timeIndex=t, subcatchIndex=j)
+                nc_catchment_timeseries[j, :, t] = np.array(catchment_results[0:num_catchment_attributes],
+                                                            dtype=np.float)
+
+            # node attributes
+            for j in range(num_nodes):
+                node_results = output.get_node_result(p_handle=file_handle, timeIndex=t, nodeIndex=j)
+                nc_node_timeseries[j, :, t] = np.array(node_results[0:num_node_attributes], dtype=np.float)
+
+            # link attributes
+            for j in range(num_links):
+                link_results = output.get_link_result(p_handle=file_handle, timeIndex=t, linkIndex=j)
+                nc_link_timeseries[j, :, t] = np.array(link_results[0:num_link_attributes], dtype=np.float)
+
+            # system attributes
+            system_results = output.get_system_result(p_handle=file_handle, timeIndex=t, dummyIndex=0)
+            nc_system_timeseries[:, t] = np.array(system_results[0:num_system_attributes], dtype=np.float)
+
+            if t % 5000 == 0:
+                netcdf_output.sync()
+
+            progress = int(t * 100 / num_steps)
+            print(rf'Progress: {progress}%/{100}', end='\r')
 
-        progress = int(t * 100 / num_steps)
-        print(rf'Progress: {progress}%/{100}', end='\r')
     netcdf_output.close()
     output.close(file_handle)
